synthetic.predictor package
===========================

Submodules
----------

synthetic.predictor.adult module
--------------------------------

.. automodule:: synthetic.predictor.adult
   :members:
   :undoc-members:
   :show-inheritance:
   :special-members:

Module contents
---------------

.. automodule:: synthetic.predictor
   :members:
   :undoc-members:
   :show-inheritance:
   :special-members:
